//
//  NBContent.h
//  NswBaaSSDK
//
//  Copyright (C) 2014 NIPPON SYSTEMWARE CO.,LTD. All rights reserved.
//

#import <Foundation/Foundation.h>

@class NBContentMain, NBContentData, NBContentPopup, NBContentTerm;

/**
 * 「全てのランドマーク」を表す定数。 【SDKバージョン2.0.0以降】
 *
 * ポスモバWEBのコンテンツ配信の作成にて、関連ランドマークに「全てのランドマーク」を指定した場合、
 *
 * relatedLandmarksに格納されているNBRelLandmarkのlandmarkIdプロパティに kNBRelLandmarkALL が格納される。
 */
extern NSString *const kNBRelLandmarkALL;

/**
 * コンテンツタイプ 【SDKバージョン2.0.0以降】
 */
typedef NS_ENUM(NSInteger, NBContentType) {
    /** クーポン */
    kNBContentTypeCoupon = 1,
    
    /** お知らせ */
    kNBContentTypeInfo = 2,
    
    /** チラシ */
    kNBContentTypeFlyer = 3
};

/**
 * コンテンツ配信情報 【SDKバージョン2.0.0以降】
 */
@interface NBContent : NSObject

/**
 * コンテンツID
 */
@property (nonatomic) NSString *contentId;

/**
 * 配信契機
 *
 * 0:通常コンテンツ
 *
 * 2:位置連動コンテンツ
 *
 * 3:周辺機器連動コンテンツ（Beacon）
 */
@property (nonatomic) int pubTiming;

/**
 * 使用上限回数
 */
@property (nonatomic) int useLimit;

/**
 * タグ
 */
@property (nonatomic) NSString *tag;

/**
 * 有効期限切れコンテンツの再有効化、コンテンツ削除後の再取得を許可するか
 *
 * ※再有効化・再取得したコンテンツの無効フラグ、使用回数、一時無効とする日時はリセットされる
 *
 * 0:非許可
 *
 * 1:許可
 */
@property (nonatomic) int reuseContent;

/**
 * 最終更新日時
 */
@property (nonatomic) NSDate *lastUpdateDate;

/**
 * 関連するランドマーク(NBRelLandmarkの配列)
 */
@property (nonatomic) NSArray *relatedLandmarks;

/**
 * コンテンツメイン情報
 */
@property (nonatomic) NBContentMain *main;

/**
 * コンテンツ追加テキストデータ
 */
@property (nonatomic) NBContentData *data;

/**
 * プッシュ通知用情報
 */
@property (nonatomic) NBContentPopup *popup;

/**
 * 期限情報
 */
@property (nonatomic) NBContentTerm *term;

/**
 * 現在の使用回数
 */
@property (nonatomic) int useCount;

/**
 * 無効フラグ
 */
@property (nonatomic) BOOL disable;

/**
 * 一時無効とする日時
 *
 * この値に設定されている日時まで、一時無効扱いとなる。
 */
@property (nonatomic) NSDate *tmpDisableDate;

/**
 * コンテンツ取得の契機となったランドマークID
 */
@property (nonatomic) NSString *opportunityLandmarkId;

/**
 * コンテンツ取得の契機となったビーコンID
 */
@property (nonatomic) int opportunityBeaconId;

@end

/**
 * 関連ランドマーク 【SDKバージョン2.0.0以降】
 */
@interface NBRelLandmark : NSObject

/**
 * ランドマークID
 */
@property (nonatomic) NSString *landmarkId;

/**
 * 名称
 */
@property (nonatomic) NSString *name;

@end

/**
 * コンテンツメイン情報 【SDKバージョン2.0.0以降】
 */
@interface NBContentMain : NSObject

/**
 * コンテンツタイプ
 */
@property (nonatomic) NBContentType type;

/**
 * コンテンツのタイトル
 */
@property (nonatomic) NSString *subject;

/**
 * コンテンツの説明
 */
@property (nonatomic) NSString *body;

/**
 * コンテンツファイル取得方法(SDKバージョン2.0.0未使用)
 */
@property (nonatomic) int fileUrlType;

/**
 * 付加データ データファイルURL
 */
@property (nonatomic) NSString *fileUrl;

@end

/**
 * コンテンツ追加テキストデータ 【SDKバージョン2.0.0以降】
 */
@interface NBContentData : NSObject

/**
 * 付加データ テキストデータ
 */
@property (nonatomic) NSString *textData;

@end

/**
 * プッシュ通知用情報 【SDKバージョン2.0.0以降】
 */
@interface NBContentPopup : NSObject

/**
 * 受信時メッセージ通知タイトル
 */
@property (nonatomic) NSString *subject;

/**
 * 受信時メッセージ本文
 */
@property (nonatomic) NSString *body;

/**
 * 付加データ 関連URL
 */
@property (nonatomic) NSString *url;

@end

/**
 * 期間情報 【SDKバージョン2.0.0以降】
 */
@interface NBContentTerm : NSObject

/**
 * 配信期間の開始日時
 */
@property (nonatomic) NSDate *termStart;

/**
 * 配信期間の終了日時
 */
@property (nonatomic) NSDate *termEnd;

/**
 * コンテンツの有効期間の開始日時
 */
@property (nonatomic) NSDate *validStart;

/**
 * コンテンツの有効期間の終了日時
 */
@property (nonatomic) NSDate *validEnd;

/**
 * コンテンツの有効日数
 */
@property (nonatomic) int validDays;

@end
