//
//  NBPushMessage.h
//  NswBaaSSDK
//
//  Copyright (C) 2014 NIPPON SYSTEMWARE CO.,LTD. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "NBContent.h"

/**
 * Push通知メッセージを表すクラス
 */
@interface NBPushMessage : NSObject

/**
 * メッセージID
 *
 * ポスモバがメッセージ配信時に設定する値。
 * 
 * メッセージ配信のたびに変化するので、同一のメッセージかどうかはこの値を比較することで判定できる。
 */
@property (nonatomic) NSString *messageId;

/**
 * メッセージ本文
 *
 * ポスモバWebで入力したメッセージの本文が入っている。
 *
 * Push通知受信時に通知センターに表示される。
 */
@property (nonatomic) NSString *body;

/**
 * JSONデータ
 *
 * ポスモバWebが送信したJSONデータをパースしたもの。
 */
@property (nonatomic) NSDictionary *userInfo;

@end

/**
 * テキスト情報のPush通知メッセージを表すクラス
 */
@interface NBTextMessage : NBPushMessage

/**
 * 連携URL
 *
 * ポスモバWebで入力した連携URLが入っている。
 */
@property (nonatomic) NSString *url;

@end

/**
 * コンテンツ情報のPush通知メッセージを表すクラス 【SDKバージョン2.0.0以降】
 */
@interface NBContentMessage : NBPushMessage

/**
 * コンテンツ情報
 *
 * ポスモバWebで入力したコンテンツ情報が入っている。
 */
@property (nonatomic) NBContent *content;

@end
