//
//  NBWiFiManager.h
//  NswBaaSSDK
//
//  Copyright (C) 2015 NIPPON SYSTEMWARE CO.,LTD. All rights reserved.
//

#import "NBWiFi.h"
#import "NBContent.h"
#import "NBPushMessage.h"
#import <CoreLocation/CoreLocation.h>

/**
 * WiFi関連delegate 【SDKバージョン3.3.0以降】
 */
@protocol NBWiFiManagerDelegate

@optional

/**
 * WiFi連動コンテンツが見つかったときに呼び出される
 *
 * @param wifi Wi-Fi
 *
 * @param content コンテンツ
 *
 * @see [NBWiFiManager delegate]
 */
- (void)didFindContentWiFi:(NBWiFi *)wifi content:(NBContent *)content;

/**
 * ポスモバに登録されているWiFiと接続した時に呼び出される
 *
 * @param wifi Wi-Fi
 *
 * @see [NBWiFiManager delegate]
 */
- (void)didConnectWiFi:(NBWiFi *)wifi;

@end

/**
 * WiFi検出機能 【SDKバージョン3.3.0以降】
 *
 * WiFi検出を開始するためには、startWiFiSearch:メソッドをコールします。
 *
 * startWiFiSearch: メソッドは、WiFi検出を実施します。
 *
 * 検出したWiFiに関連したWiFi連動コンテンツが見つかった場合、
 *
 * アプリがフォアグラウンドの時のみ起動。
 *
 * [ 使用方法 ]
 *
 * ①startWiFiSearch: - 成功
 *
 * ②適宜delegateが呼び出される。
 *
 * 　[NBWiFiManagerDelegate didFindContentWiFi:content:] (アプリがフォアグラウンドの場合のみ)
 *
 * ③stopWiFiSearch: - 検出の停止
 */
@interface NBWiFiManager : NSObject

/**
 * delegate
 */
@property (weak) id<NBWiFiManagerDelegate> delegate;

/**
 * 現在検出しているWiFi(NBWifiの配列)
 */
@property (nonatomic) NSArray *detectedWiFis;

/**
 * Wi-Fi接続時のコネクティビティ連携コンテンツ取得有効/無効設定 【SDKバージョン3.3.0以降】
 *
 * @param enable 有効/無効
 *
 */
- (BOOL)setEnableWiFiConnectPush:(BOOL)enable;

@end
