//
//  AppDelegate.m
//

#import "AppDelegate.h"
#import <NswBaaSSDK/NBNswBaaSManager.h>
#import <NswBaaSSDK/NBContentsRequest.h>

//#define SDK_ID @"Webにて発行されたSDK-IDに置き換えてください"

@interface AppDelegate() <NBNswBaaSManagerDelegate, NBNswBaaSContentDelegate>

@property NBNswBaaSManager *manager;

@end

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
    //NSW BaaS Managerの初期設定
    if (!self.manager) {
        self.manager = [NBNswBaaSManager sharedManager];
        self.manager.delegate = self;
        
        //コンテンツ取得関連delegateを設定
        self.manager.contentDelegate = self;
        [self.manager initializeWithSdkId:SDK_ID];
        
        //--------------------------------------------------
        //適宜、設定を変更してください。
        //
        //デバッグモードに設定する。(デフォルトはNO:リリースモード)
        //[self.manager setDebug:YES];
        //
        //Push通知受信時、SDKに処理をさせない。(デフォルトはYES)
        //[self.manager setPushMessageAutoPlay:NO];
        //
        //Push通知、位置連動配信を無効にする。(デフォルトは両方ともYES)
        //[self.manager setPermissionPush:NO location:NO];
        //
        //利用者情報1にシステムのロケールを、利用者情報2にシステムのタイムゾーンを設定する。
        //[self.manager setUserData:[[NSLocale currentLocale] localeIdentifier]
        //                    data2:[NSTimeZone systemTimeZone].name
        //                    data3:nil
        //                    data4:nil
        //                    data5:nil];
        //--------------------------------------------------
    }
    
    //起動時のオプションをSDKに送る
    [self.manager didFinishLaunchingWithOptions:launchOptions];
    
    return YES;
}

- (void)applicationDidEnterBackground:(UIApplication *)application
{
    //SDKの処理を中断する
    [self.manager pause];
}

- (void)applicationWillEnterForeground:(UIApplication *)application
{
    //SDKの処理を再開する
    [self.manager resume];
}

- (void)application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)devToken
{
    //取得したデバイストークンをSDKに送る
    [self.manager didRegisterForRemoteNotificationsWithDeviceToken:devToken];
}

- (void)application:(UIApplication *)application didFailToRegisterForRemoteNotificationsWithError:(NSError *)error
{
    //エラー情報をSDKに送る
    [self.manager didFailToRegisterForRemoteNotificationsWithError:error];
}

- (void)application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo
{
    //受信したRemoteNotificationの情報をSDKに送る
    [self.manager didReceiveRemoteNotification:userInfo];
}

- (void)application:(UIApplication *)application didReceiveLocalNotification:(UILocalNotification *)notification
{
    //受信したLocalNotificationの情報をSDKに送る
    [self.manager didReceiveLocalNotification:notification];
}

- (void)didRegister
{
    NSLog(@"クライアント登録成功");
}

- (void)didFailToRegister:(NBRegisterError)reason
{
    NSLog(@"クライアント登録失敗");
    //クライアント登録に失敗した場合本コールバックが呼ばれる。
    //自動でリトライするため、登録が成功した段階でdidRegister:がコールされる。
}

- (IBAction)clickedButton:(id)sender {
    if (![self.manager isRegistered]) {
        NSLog(@"クライアント未登録");
        return;
    }

    //ボタンがタップされたらコンテンツを取得する。
    NBContentsRequest *request = [NBContentsRequest new];
    //「クーポンのみ」を指定
    request.contentType = kNBContentTypeFlagCoupon;
    // コンテンツの取得要求
    [self.manager requestContents:request];
}

/**
 * Push配信メッセージ受信時に呼び出される。
 */
- (void)didReceivedPushMessage:(NBPushMessage *)message
{
    //--------------------------------------------------
    // Push配信メッセージを受信したときの処理を記載してください。
    //
    // 例：メッセージ本文をアラートで表示する
    //  UIAlertView *alert = [[UIAlertView alloc] initWithTitle:nil
    //                                                  message:message.body
    //                                                 delegate:nil
    //                                        cancelButtonTitle:@"OK"
    //                                        otherButtonTitles:nil];
    //  [alert show];
    //
    // 例：外部ブラウザを起動して連携URLを開く
    //  if ([message isKindOfClass:[NBTextMessage class]]) {
    //      NBTextMessage *textMessage = (NBTextMessage *)message;
    //      [[UIApplication sharedApplication] openURL:[NSURL URLFromString:textMessage.url]];
    //  }
    //--------------------------------------------------
}

/**
 * ランドマーク取得(requstLandmark)終了時に呼び出される。
 */
- (void)didFinishedRequestLandmark:(NSArray *)landmarks
{
    NSLog(@"ランドマークの取得が終了しました");
}

/** コンテンツ取得(requestContents)終了時に呼び出される。*/
- (void)didLoadLocalContents:(NBContentsRequest *)request contents:(NSArray *)contents
{
    // SDK内部保存情報のコールバック
    NSLog(@"取得済みコンテンツ %@", contents);
    
    for (NBContent *content in contents) {
        //付加データファイルURLがある場合は展開後フォルダを取得
        if ([content.main.fileUrl length]) {
            [self.manager requestDownloadContentData:content.contentId];
        }
    }
}

/** コンテンツ情報変更ありの時に呼び出される。 */
- (void)didReceiveUpdateExist:(NBContentsRequest *)request
{
    NSLog(@"コンテンツアップデートあり");
}

/** コンテンツ情報変更なしの時に呼び出される。 */
- (void)didReceiveNoUpdateExist:(NBContentsRequest *)request
{
    NSLog(@"コンテンツアップデートなし");
}

/** コンテンツ付加データ展開終了時に呼び出される。 */
- (void)didDownloadContentDataInDirectory:(NSString *)dir
{
    if (!dir) {
        NSLog(@"コンテンツ付加データの展開に失敗しました");
    } else {
        NSLog(@"コンテンツ付加データ展開フォルダ:%@", dir);
    }
}

@end
